@@ -3,6 +3,8 @@
 
 # imports.
 import os, sys, syst3m ; sys.path.insert(1, syst3m.defaults.source_path(__file__, back=2))
+os.environ["CLI"] = "True"
+os.environ["START_ENCRYPTION"] = "True"
 from ssht00ls.classes.config import *
 import ssht00ls
 
