@@ -8,8 +8,17 @@ from ssht00ls.classes.agent import agent
 
 # the aliases object class.
 class Aliases(object):
-	def __init__(self):
-		a=1
+	def __init__(self,
+		# initialize as specific not global (optional).
+		# 	the initialized alias.
+		alias=None,
+	):
+		
+		# specific variables.
+		self.specific = alias != None
+		self.alias = alias
+
+		#
 	def list(self):
 		array = []
 		for i in list(CONFIG["aliases"].keys()):
@@ -24,7 +33,7 @@ class Aliases(object):
 		return items
 	def check(self, 
 		# the alias to check.
-		alias, 
+		alias=None, 
 		# the info to check.
 		# 	adds / replaces the current (except the exceptions).
 		info={},
@@ -36,6 +45,10 @@ class Aliases(object):
 		create=False,
 	):
 
+		# check specific.
+		if self.specific:
+			if alias == None: alias = self.alias
+
 		# get info.
 		current_info, exists, edits = {}, False, 0
 		try: current_info = CONFIG["aliases"][alias]
@@ -70,18 +83,30 @@ class Aliases(object):
 		return r3sponse.success(f"Successfully checked alias {alias}.")
 
 		#
-	def check_duplicate(self, alias):
+	def check_duplicate(self, alias=None):
+		# check specific.
+		if self.specific:
+			if alias == None: alias = self.alias
+		# check.
 		try: CONFIG["aliases"][alias]
 		except KeyError:
 			return r3sponse.success(f"Alias {alias} does not exist.")
 		return r3sponse.error(f"Alias {alias} already exists.")
-	def info(self, alias):
+	def info(self, alias=None):
+		# check specific.
+		if self.specific:
+			if alias == None: alias = self.alias
+		# check.
 		response = self.check(alias)
 		if not response["success"]: return response
 		return r3sponse.success(f"Successfully listed the info of alias {alias}.", {
 			"info":CONFIG["aliases"][alias],
 		})
-	def delete(self, alias):
+	def delete(self, alias=None):
+		# check specific.
+		if self.specific:
+			if alias == None: alias = self.alias
+		# check.
 		response = self.check(alias)
 		if not response["success"]: return response
 		del CONFIG["aliases"][alias]
@@ -123,6 +148,10 @@ class Aliases(object):
 					dictionary[key] = value
 					c += 1
 			return dictionary, c
+		# check specific.
+		if self.specific:
+			if alias == None: alias = self.alias
+		# check.
 		response = self.check(alias)
 		if not response["success"]: return response
 		dictionary, c = edit_dict(dictionary=CONFIG.dictionary, edits=edits)
@@ -160,7 +189,7 @@ class Aliases(object):
 		# serialized all parameters as dict, except: [save].
 		serialized={},
 	):
-		
+
 		# serialized
 		if serialized != {}:
 			username, public_ip, private_ip, public_port, private_port, private_key, public_key, passphrase, smart_card, pin, alias = Dictionary(serialized).unpack({
@@ -176,6 +205,10 @@ class Aliases(object):
 				"pin":None,
 				"alias":None,
 			})
+		
+		# check specific.
+		if self.specific:
+			if alias == None: alias = self.alias
 
 		# checks.
 		response = r3sponse.check_parameters({
@@ -200,6 +233,10 @@ class Aliases(object):
 			}, empty_value=None)
 			if not response["success"]: return response
 
+		# check encryption activated.
+		if not encryption.activated:
+			return r3sponse.error("The encryption requires to be activated.")
+
 		# duplicate.
 		if checks:
 			response = self.check_duplicate(alias)
@@ -248,11 +285,11 @@ class Aliases(object):
 		# passphrase.
 		if passphrase not in [False, "", "none", None, "None"]:
 			if smart_card:
-				response = ENCRYPTION.encrypt(str(pin))
+				response = encryption.encryption.encrypt(str(pin))
 				if not response["success"]: return response
 				json_config["pin"] = response["encrypted"].decode()
 			else:
-				response = ENCRYPTION.encrypt(str(passphrase))
+				response = encryption.encryption.encrypt(str(passphrase))
 				if not response["success"]: return response
 				json_config["passphrase"] = response["encrypted"].decode()
 		else:
@@ -271,6 +308,9 @@ class Aliases(object):
 		})
 	def sync(self):
 		if not Files.exists(f"{HOME}/.ssh"): os.system(f"mkdir {HOME}/.ssh && chown -R {OWNER}:{GROUP} {HOME}/.ssh && chmod 700 {HOME}/.ssh")
+		# check encryption activated.
+		if not encryption.activated:
+			return r3sponse.error("The encryption requires to be activated.")
 		include = f"include ~/.ssht00ls/lib/aliases"
 		if not Files.exists(f"{HOME}/.ssh/config"): 
 			Files.save(f"{HOME}/.ssh/config", include)
@@ -315,7 +355,7 @@ class Aliases(object):
 								passphrase =  getpass.getpass(f"Enter the passphrase of key {checked['private_key']}:")
 						else:
 							new_passphrase = False
-							response = ENCRYPTION.decrypt(checked["pin"])
+							response = encryption.encryption.decrypt(checked["pin"])
 							if not response.success: return response
 							passphrase = response.decrypted.decode()
 					else:	
@@ -326,7 +366,7 @@ class Aliases(object):
 								passphrase =  getpass.getpass(f"Enter the passphrase of key {checked['private_key']}:")
 						else:
 							new_passphrase = False
-							response = ENCRYPTION.decrypt(checked["passphrase"])
+							response = encryption.encryption.decrypt(checked["passphrase"])
 							if not response.success: return response
 							passphrase = response.decrypted.decode()
 					if has_passphrase:
@@ -344,7 +384,7 @@ class Aliases(object):
 									response = agent.add(path=checked["private_key"], passphrase=passphrase)
 									if not response["success"]: return response
 						if new_passphrase:
-							response = ENCRYPTION.encrypt(passphrase)
+							response = encryption.encryption.encrypt(passphrase)
 							if not response.success: return response
 							if checked["smart_card"] == True:
 								CONFIG["aliases"][alias]["pin"] = response.encrypted.decode()
