@@ -51,6 +51,7 @@ LOG_LEVEL = syst3m.defaults.log_level(default=0)
 syst3m.defaults.alias(alias=ALIAS, executable=f"{SOURCE_PATH}")
 
 # universal options.
+CLI = syst3m.env.get_boolean("CLI")
 INTERACTIVE = not cl1.arguments_present(["--non-interactive"])
 CHECKS = not cl1.arguments_present(["--no-checks"])
 JSON = cl1.arguments_present(["-j", "--json"])
@@ -153,98 +154,47 @@ if CHECKS and not cl1.arguments_present("--reset-cache"):
 		if cl1.argument_present("--stop-agent"):
 			response = webserver.stop()
 			if response.success:
-				r3sponse.log(response=response, json=json)
+				r3sponse.log(response=response, json=syst3m.defaults.options.json)
 				sys.exit(0)
 			else:
-				r3sponse.log(response=response, json=json)
+				r3sponse.log(response=response, json=syst3m.defaults.options.json)
 				sys.exit(1)
 		elif cl1.argument_present("--start-agent"):
 			if not webserver.running(): 
 				webserver.start()
 				sys.exit(0)
 			else:
-				r3sponse.log(error=f"The {webserver.id} is already running.", json=JSON)
+				r3sponse.log(error=f"The {webserver.id} is already running.", json=syst3m.defaults.options.json)
 				sys.exit(1)
 		elif INTERACTIVE and not webserver.running(): 
 			response = webserver.fork()
-			r3sponse.log(response=response, json=JSON)
+			r3sponse.log(response=response, json=syst3m.defaults.options.json)
 			if not response.success: sys.exit(0)
 
 		# encryption.
-		passphrase = None
-		if None in [CONFIG.dictionary["encryption"]["public_key"], CONFIG.dictionary["encryption"]["private_key"]]:
-			if INTERACTIVE:
-				passphrase = getpass.getpass("Enter the passphrase of the ssht00ls encryption:")
-				if len(passphrase) < 8: 
-					r3sponse.log(error="The passphrase must contain at least 8 characters.", json=cl1.arguments_present(["--json", "-j"]))
-					sys.exit(1)
-				elif passphrase.lower() == passphrase: 
-					r3sponse.log(error="The passphrase must contain capital characters.", json=cl1.arguments_present(["--json", "-j"]))
-					sys.exit(1)
-				elif passphrase != getpass.getpass("Enter the same passphrase:"): 
-					r3sponse.log(error="The passphrase must contain at least 8 characters.", json=cl1.arguments_present(["--json", "-j"]))
-					sys.exit(1)
-				ENCRYPTION = encrypti0n.aes.AsymmetricAES(
-					public_key=CONFIG.dictionary["encryption"]["public_key"],
-					private_key=CONFIG.dictionary["encryption"]["public_key"],
-					passphrase=passphrase,
-					memory=True,)
-				response = ENCRYPTION.generate_keys()
-				if not response["success"]: 
-					r3sponse.log(error=f"Encoutered an error while generating the master encryption key: {response['error']}", json=cl1.arguments_present(["--json", "-j"]))
-					sys.exit(1)
-				ENCRYPTION.rsa.private_key = response.private_key
-				ENCRYPTION.rsa.public_key = response.public_key
-				CONFIG.dictionary["encryption"]["public_key"] = ENCRYPTION.rsa.public_key
-				CONFIG.dictionary["encryption"]["private_key"] = ENCRYPTION.rsa.private_key
-				CONFIG.save()
-				response = ENCRYPTION.load_keys()
-				if not response["success"]: 
-					r3sponse.log(error=f"Encoutered an error while activating the ssht00ls encryption: {response['error']}", json=cl1.arguments_present(["--json", "-j"]))
-					sys.exit(1)
-				response = webserver.set(group="passphrases", id="master", data=passphrase)
-				if not response["success"]: 
-					r3sponse.log(error=f"Encoutered an error while caching the passphrase (#1): {response['error']}", json=cl1.arguments_present(["--json", "-j"]))
-					sys.exit(1)
-			else:
-				r3sponse.log(error="There is no encryption installed.", json=JSON)
-				sys.exit(1)
-		else:
-			response, new, passphrase = webserver.get(group="passphrases", id="master"), False, None
-			if response["success"]:
-				passphrase = response["data"]
-			if passphrase in [False, None, "", "null", "None", "none"]:
-				if not INTERACTIVE:
-					r3sponse.log(error=response.error, json=JSON)
-					sys.exit(1)
+		from ssht00ls.classes import encryption as _encryption_
+		encryption = _encryption_.Encryption(
+			config=CONFIG,
+			webserver=webserver,
+			cache=f"{syt3m.defaults.vars.home}/.{ALIAS}/.cache.enc/",
+			interactive=INTERACTIVE,)
+
+		# generate.
+		if syst3m.env.get_boolean("START_ENCRYPTION"):
+			if None in [CONFIG.dictionary["encryption"]["public_key"], CONFIG.dictionary["encryption"]["private_key"]]:
+				if CLI:
+					response = encryption.generate()
+					r3sponse.log(response=response, json=syst3m.defaults.options.json)
+					if not response.success: sys.exit(1)
 				else:
-					new = True
-					passphrase = getpass.getpass("Enter the passphrase of the ssht00ls encryption:")
-			ENCRYPTION = encrypti0n.aes.AsymmetricAES(
-				public_key=CONFIG.dictionary["encryption"]["public_key"],
-				private_key=CONFIG.dictionary["encryption"]["private_key"],
-				passphrase=passphrase,
-				memory=True,)
-			response = ENCRYPTION.load_keys()
-			if not response["success"]: 
-				r3sponse.log(error=f"Encoutered an error while activating the ssht00ls encryption: {response['error']}", json=cl1.arguments_present(["--json", "-j"]))
-				sys.exit(1)
-			if new:
-				response = webserver.set(group="passphrases", id="master", data=passphrase)
-				if not response["success"]: 
-					r3sponse.log(error=f"Encoutered an error while caching the passphrase (#2): {response['error']}", json=cl1.arguments_present(["--json", "-j"]))
+					r3sponse.log(error="There is no encryption installed.", json=syst3m.defaults.options.json)
 					sys.exit(1)
 
-		# encrypted database.
-		if passphrase not in [False, None, "", "null", "None", "none"]:
-			ENCRYPTED_DATABASE = encrypti0n.aes.Database(path=f"{HOME}/.{ALIAS}/.cache.enc/", aes=ENCRYPTION)
-			response = ENCRYPTED_DATABASE.activate()
-			if not response["success"]: 
-				r3sponse.log(error=f"Encoutered an error while activating the encrypted cache: {response['error']}", json=cl1.arguments_present(["--json", "-j"]))
-				sys.exit(1)
+			# activate.
+			else:
 
-			#
-
-		# reset variables.
-		passphrase = None
+				# activate encryption.
+				response = encryption.activate()
+				r3sponse.log(response=response, json=syst3m.defaults.options.json)
+				if not response.success: sys.exit(1)
 
