@@ -50,8 +50,7 @@ class SCP(object):
 
 		# check client path.
 		if Files.exists(client_path):
-			response["error"] = f"Client path [{client_path}] already exists."
-			return response
+			return r3sponse.error(f"Client path [{client_path}] already exists.")
 
 		# do.
 		command = self.__build__(
@@ -65,25 +64,19 @@ class SCP(object):
 		
 		# check fails.
 		if "No such file or directory" in output:
-			response["error"] = f"Server path [{server_path}] does not exist."
-			return response
+			return r3sponse.error(f"Server path [{server_path}] does not exist.")
 		elif "not a regular file" in output:
-			response["error"] = f"Server path [{server_path}] is a directory."
-			return response
+			return r3sponse.error(f"Server path [{server_path}] is a directory.")
 		elif "" == output:
 			if not Files.exists(client_path):
-				response["error"] = f"Failed to download [{server_path}]."
-				return response
+				return r3sponse.error(f"Failed to download [{server_path}].")
 			# check success.	
 			else:
-				response["success"] = True
-				response["message"] = f"Successfully downloaded [{server_path}]."
-				return response
+				return r3sponse.success(f"Successfully downloaded [{server_path}].")
 		# unknown.
 		else:
 			l = f"Failed to download [{client_path}]"
-			response["error"] = (f"{l}, error: "+output.replace("\n", ". ").replace(". .", ".")+".)").replace(". .",".").replace("\r","").replace("..",".")
-			return response
+			return r3sponse.error((f"{l}, error: "+output.replace("\n", ". ").replace(". .", ".")+".)").replace(". .",".").replace("\r","").replace("..","."))
 		
 		#
 	def upload(self, 
@@ -122,8 +115,7 @@ class SCP(object):
 
 		# check client path.
 		if not Files.exists(client_path):
-			response["error"] = f"Client path [{client_path}] does not exist."
-			return response
+			return r3sponse.error(f"Client path [{client_path}] does not exist.")
 
 		# do.
 		command = self.__build__(
@@ -137,20 +129,15 @@ class SCP(object):
 
 		# check fails.
 		if "No such file or directory" in output:
-			response["error"] = f"The base path [{FilePath(server_path).base()}] of the specified file does not exist on the server."
-			return response
+			return r3sponse.error(f"The base path [{FilePath(server_path).base()}] of the specified file does not exist on the server.")
 		elif "not a regular file" in output:
-			response["error"] = f"Client path [{client_path}] is a directory."
-			return response
+			return r3sponse.error(f"Client path [{client_path}] is a directory.")
 		elif "" == output:
-			response["success"] = True
-			response["message"] = f"Successfully uploaded [{client_path}]."
-			return response
+			return r3sponse.success(f"Successfully uploaded [{client_path}].")
 		# unknown.
 		else:
 			l = f"Failed to upload [{client_path}]"
-			response["error"] = (f"{l}, error: "+output.replace("\n", ". ").replace(". .", ".")+".)").replace(". .",".").replace("\r","").replace("..",".")
-			return response
+			return r3sponse.error((f"{l}, error: "+output.replace("\n", ". ").replace(". .", ".")+".)").replace(". .",".").replace("\r","").replace("..","."))
 		
 		#
 	# system functions.
