@@ -23,7 +23,7 @@ class SmartCards(object):
 				"/usr/lib/arm-linux-gnueabihf/opensc-pkcs11.so",
 				"/usr/local/lib/libykcs11",
 			]:
-				if os.path.exists(path):
+				if Files.exists(path):
 					self.path = path
 					break
 			if self.path == None: raise ValueError("Unable to locate opensc-pkcs11.so path.")
@@ -34,7 +34,7 @@ class SmartCards(object):
 			#self.original_path = "/usr/local/lib/opensc-pkcs11.so"
 			self.original_path = f"{SOURCE_PATH}/lib/opensc/macos/opensc-pkcs11.so"
 			self.path = "/usr/local/lib/opensc-pkcs11_NOTALINK.so"
-			if not os.path.exists(self.original_path):
+			if not Files.exists(self.original_path):
 				raise OSError("opensc package is not installed, run: [$ brew install yubico-piv-tool opensc].")
 
 	def scan(self, silent=False):
@@ -339,7 +339,7 @@ class SmartCard(object):
 			# write out.
 			if path != None:
 				try:
-					utils.__save_file__(path, utils.__array_to_string__(output, joiner="\n"))
+					Files.save(path, utils.__array_to_string__(output, joiner="\n"))
 				except:
 					return r3sponse.error(f"Failed to write out the exported key from smart card [{self.serial_number}].")
 
