@@ -6,6 +6,22 @@ from ssht00ls.classes.config import *
 import os, sys, json, subprocess
 
 # execute.
+def check_errors(output):
+	for i in [
+		"rsync: ",
+		"rsync error: ",
+		"ssh: ",
+		"ssh error: ",
+		"client_loop: send disconnect: Broken pipe",
+	]:
+		if i in output:
+			e = String(i+output.split(i)[1].split("\n")[0]).capitalized_word().replace("Client_loop: send disconnect:", "Client loop: send disconnect:").replace("Ssh", "SSH")
+			while True:
+				if len(e) > 0 and e[len(e)-1] in [" ", "."]: e = e[:-1]
+				elif len(e) > 0 and e[0] in [" "]: e = e[1:]
+				else: break
+			return r3sponse.error(e+".")
+	return r3sponse.success("The output contains no (default) errors.")
 def execute( 
 	# the command in str.
 	command="ls",
@@ -96,23 +112,7 @@ def execute(
 	#
 
 # test ssh functions.
-def check_errors(output):
-	for i in [
-		"rsync: ",
-		"rsync error: ",
-		"ssh: ",
-		"ssh error: ",
-		"client_loop: send disconnect: Broken pipe",
-	]:
-		if i in output:
-			e = String(i+output.split(i)[1].split("\n")[0]).capitalized_word().replace("Client_loop: send disconnect:", "Client loop: send disconnect:").replace("Ssh", "SSH")
-			while True:
-				if len(e) > 0 and e[len(e)-1] in [" ", "."]: e = e[:-1]
-				elif len(e) > 0 and e[0] in [" "]: e = e[1:]
-				else: break
-			return r3sponse.error(e+".")
-	return r3sponse.success("The output contains no (default) errors.")
-def test_ssh(alias=None, accept_new_host_keys=True, checks=True):
+def test(alias=None, accept_new_host_keys=True, checks=True):
 	accept_new_host_keys = Boolean(accept_new_host_keys).convert(true="printf 'yes' | ", false="")
 	output = syst3m.utils.__execute_script__(f"""{accept_new_host_keys}ssh {DEFAULT_SSH_OPTIONS} {alias} ' echo "Hello World" ' """)
 	response = check_errors(output)
@@ -122,7 +122,7 @@ def test_ssh(alias=None, accept_new_host_keys=True, checks=True):
 		return r3sponse.success(f"Successfully connected with {alias}.")
 	else:
 		return r3sponse.error(f"Failed to connect with {alias}, error: {output}")
-def test_ssh_path(alias=None, path=None, accept_new_host_keys=True, checks=True):
+def test_path(alias=None, path=None, accept_new_host_keys=True, checks=True):
 	if checks:
 		response = test_ssh(alias=alias, accept_new_host_keys=accept_new_host_keys)
 		if not response.success: return response
@@ -134,7 +134,7 @@ def test_ssh_path(alias=None, path=None, accept_new_host_keys=True, checks=True)
 		return r3sponse.success(f"Path {alias}:{path} exists.")
 	else:
 		return r3sponse.error(f"Path {alias}:{path} does not exist.")
-def test_ssh_dir(alias=None, path=None, accept_new_host_keys=True, create=False, created=False, checks=True):
+def test_dir(alias=None, path=None, accept_new_host_keys=True, create=False, created=False, checks=True):
 	if checks:
 		response = test_ssh(alias=alias, accept_new_host_keys=accept_new_host_keys)
 		if not response.success: return response
@@ -156,7 +156,7 @@ def test_ssh_dir(alias=None, path=None, accept_new_host_keys=True, create=False,
 			return r3sponse.error(f"Path {alias}:{path} is not a directory.")
 	else:
 		return r3sponse.error(f"Unable to check remote directory {alias}:{path}, output: {output}.")
-def test_ssht00ls(alias=None, accept_new_host_keys=True, install=True):
+def testt00ls(alias=None, accept_new_host_keys=True, install=True):
 	for path in [f"/usr/local/lib/{ALIAS}"]:
 		response = test_ssh_path(alias=alias, accept_new_host_keys=accept_new_host_keys, path=path)
 		if not response.success:
@@ -205,7 +205,7 @@ def ssh_agent():
 	os.environ["SSH_AGENT_PID"] = SSH_AGENT_PID
 
 # kill all ssh procs with that includes the identifier.
-def kill_ssh(identifier=None, sudo=False, dont_kill=["grep", "ssht00ls"]):
+def kill(identifier=None, sudo=False, dont_kill=["grep", "ssht00ls"]):
 	response = r3sponse.check_parameters({
 		"identifier:str":identifier,})
 	if not response.success: return response
