@@ -151,6 +151,10 @@ class SSync(object):
 			return r3sponse.error(f"Define parameter: path.")
 		path = gfp.clean(path)
 
+		# check encryption activated.
+		if not encryption.activated:
+			return r3sponse.error("The encryption requires to be activated.")
+
 		# remote.
 		if alias != None:
 
@@ -163,9 +167,9 @@ class SSync(object):
 
 				# check passphrase.
 				if CONFIG["aliases"][alias]["smart_card"] in [True, "true", "True"]:
-					response = ENCRYPTION.decrypt(CONFIG["aliases"][alias]["passphrase"])
+					response = encryption.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
 				else:
-					response = ENCRYPTION.decrypt(CONFIG["aliases"][alias]["passphrase"])
+					response = encryption.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
 				if not response["success"]: return response
 				passphrase = response.decrypted.decode()
 				
@@ -277,11 +281,14 @@ class SSync(object):
 		# get the command in str.
 		command=False,
 	):	
+		# check encryption activated.
+		if not encryption.activated:
+			return r3sponse.error("The encryption requires to be activated.")
 		if checks:
 			if CONFIG["aliases"][alias]["smart_card"] in [True, "true", "True"]:
-				response = ENCRYPTION.decrypt(CONFIG["aliases"][alias]["passphrase"])
+				response = encryption.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
 			else:
-				response = ENCRYPTION.decrypt(CONFIG["aliases"][alias]["passphrase"])
+				response = encryption.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
 			if not response["success"]: return response
 			passphrase = response.decrypted.decode()
 			response = aliases.check(alias)
@@ -341,11 +348,14 @@ class SSync(object):
 		# get the command in str.
 		command=False,
 	):
+		# check encryption activated.
+		if not encryption.activated:
+			return r3sponse.error("The encryption requires to be activated.")
 		if checks:
 			if CONFIG["aliases"][alias]["smart_card"] in [True, "true", "True"]:
-				response = ENCRYPTION.decrypt(CONFIG["aliases"][alias]["passphrase"])
+				response = encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
 			else:
-				response = ENCRYPTION.decrypt(CONFIG["aliases"][alias]["passphrase"])
+				response = encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
 			if not response["success"]: return response
 			passphrase = response.decrypted.decode()
 			response = aliases.check(alias)
